@@ -1,4 +1,4 @@
-##' @S3method summary bptwin
+##' @export
 summary.bptwin <- function(object,level=0.05,transform=FALSE,...) {
   logit <- function(p) log(p/(1-p))
   tigol <- function(z) 1/(1+exp(-z))
@@ -127,10 +127,13 @@ summary.bptwin <- function(object,level=0.05,transform=FALSE,...) {
     mu.cond <- function(x) m+S[1,2]/S[2,2]*(x-m)
     var.cond <- S[1,1]-S[1,2]^2/S[2,2]    
     conc <- pmvn(upper=c(m,m),sigma=S)
+    disconc <- pmvn(lower=c(-Inf,m),upper=c(m,Inf),sigma=S)
     marg <- pnorm(m,sd=S[1,1]^0.5)
     cond <- conc/marg
+    discond <- disconc/(1-marg)
+    logOR <- log(cond)-log(1-cond)-log(discond)+log(1-discond)
     lambdaR <- cond/marg
-    c(logit(c(conc,cond,marg)),lambdaR)
+    c(logit(c(conc,cond,marg)),lambdaR,logOR)
   }
 
   mycoef <- coef(object)
@@ -152,7 +155,7 @@ summary.bptwin <- function(object,level=0.05,transform=FALSE,...) {
   probMZ[1:3,] <- tigol(probMZ[1:3,])
   probDZ <- cbind(probDZ,probDZ-qnorm(1-alpha)*sprobDZ,probDZ+qnorm(1-alpha)*sprobDZ)
   probDZ[1:3,] <- tigol(probDZ[1:3,])
-  rownames(probMZ) <- rownames(probDZ) <- c("Concordance","Casewise Concordance","Marginal","Rel.Recur.Risk")
+  rownames(probMZ) <- rownames(probDZ) <- c("Concordance","Casewise Concordance","Marginal","Rel.Recur.Risk","log(OR)")
   colnames(probMZ) <- colnames(probDZ) <- c("Estimate",CIlab)
  
   ## mu <- coef(object)[c(object$bidx0[1],object$bidx1[1])]
@@ -202,19 +205,20 @@ summary.bptwin <- function(object,level=0.05,transform=FALSE,...) {
               coef=newcoef, all=all,
               vcov=vcov(object),
               AIC=AIC(object),
+              time=attributes(object)$time,
               logLik=logLik(object)) ##, concordance=concordance, conditional=conditional)
 
   class(res) <- "summary.bptwin"
   res
 }
 
-##' @S3method print summary.bptwin
+##' @export
 print.summary.bptwin <- function(x,digits = max(3, getOption("digits") - 2),...) {
   cat("\n")
   printCoefmat(x$par,digits=digits,...)
   cat("\n")
   ##  x$Nstr <- x$Nstr[,which((colnames(x$Nstr)!="Complete MZ/DZ")),drop=FALSE]
-  NN <- x$Nstr[,2:3,drop=FALSE]; colnames(NN)[1] <- gsub("Complete ","",colnames(NN)[1])
+  NN <- x$Nstr[,c(1,3),drop=FALSE]; colnames(NN)[1] <- gsub("Complete ","",colnames(NN)[1])
   print(NN,quote=FALSE)
   cat("\n")
   cc <- rbind(x$coef[,-2,drop=FALSE],x$rhoOS)
@@ -228,4 +232,9 @@ print.summary.bptwin <- function(x,digits = max(3, getOption("digits") - 2),...)
   cat("\n")
   print(RoundMat(x$heritability[,-2,drop=FALSE],digits=digits),quote=FALSE)
   cat("\n")
+  if (!is.null(x$time)) {
+      cat("\n")
+      cat("Event of interest before time ", x$time, "\n", sep="")
+  }
+
 }
